import React from 'react'

import { ErrorComponent } from '../../../../src/components/ErrorComponent'
import { GetServerSideProps } from 'next'
import { serverSideTranslations } from 'next-i18next/serverSideTranslations'
import { useShow, useTranslate, useParsed, useCustom, useApiUrl } from '@refinedev/core'
import { Show } from '@refinedev/mui'
import { Typography } from '@mui/material'
import CircularProgress from '@mui/material/CircularProgress'
import Box from '@mui/material/Box'
import Stack from '@mui/material/Stack'
import Chip from '@mui/material/Chip'
import Link from '@mui/material/Link'

const ShowFDO = () => {
  const { params } = useParsed()
  const showId = `${params?.prefix}/${params?.suffix}`
  const apiUrl = useApiUrl()
  const t = useTranslate()
  const { data, isLoading, isError, error } = useCustom({
    url: `${apiUrl}/fdo/${showId}`,
    method: 'get',
    errorNotification: () => false,
    queryOptions: {
      retry: false
    }
  })

  if (isError) {
    console.log('error', error)
    return <ErrorComponent message={t('fdo.show.handle_not_found', 'Handle not found.')} />
  }

  console.log('show', data)
  const handleUrl = `https://hdl.handle.net/${showId}`

  return (
    <Show
      isLoading={isLoading}
      title={<Typography variant="h5">{ showId }{ !isLoading && (data?.data?.isFdo ? <Chip label="FDO" color="success" variant="outlined" /> : <Chip label="Not an FDO" color="error" variant="outlined" />)}</Typography>}
    >
      { isLoading && <Box sx={{ textAlign: 'center' }}><CircularProgress/></Box>}
      <Stack>
        <Box><Link href={handleUrl}>To Repository</Link></Box>
        <Box><Link href={`${handleUrl}?noredirect`}>View Handle Record</Link></Box>
      </Stack>
    </Show>

  )
}

export default ShowFDO

export const getServerSideProps: GetServerSideProps<{}> = async (context) => {
  const translateProps = await serverSideTranslations(context.locale ?? 'en', [
    'common'
  ])

  return {
    props: {
      ...translateProps
    }
  }
}
